@@ -1,5 +1,6 @@
-"use strict";
+'use strict';
 
+// eslint-disable-next-line new-cap
 var encoder = new require('node-html-encoder').Encoder();
 
 /**
@@ -11,7 +12,7 @@ module.exports = function typeInlineTagDef(getTypeClass) {
   return {
     name: 'type',
     handler: function(doc, tagName, tagDescription) {
-      return '<a href="" class="' + getTypeClass(tagDescription) + '">'+encoder.htmlEncode(tagDescription) + '</a>';
+      return '<a href="" class="' + getTypeClass(tagDescription) + '">' + encoder.htmlEncode(tagDescription) + '</a>';
     }
   };
-};
\ No newline at end of file
+};
