@@ -17,9 +17,9 @@ module.exports = function defaultDeployment(getVersion) {
       '../angular-sanitize.min.js',
       '../angular-touch.min.js',
       '../angular-animate.min.js',
-      'components/marked-' + getVersion('marked', 'node_modules', 'package.json') + '/lib/marked.js',
+      'components/marked-' + getVersion('marked') + '/marked.min.js',
       'js/angular-bootstrap/dropdown-toggle.min.js',
-      'components/lunr.js-' + getVersion('lunr.js') + '/lunr.min.js',
+      'components/lunr-' + getVersion('lunr') + '/lunr.min.js',
       'components/google-code-prettify-' + getVersion('google-code-prettify') + '/src/prettify.js',
       'components/google-code-prettify-' + getVersion('google-code-prettify') + '/src/lang-css.js',
       'js/current-version-data.js',
@@ -30,8 +30,8 @@ module.exports = function defaultDeployment(getVersion) {
     ],
     stylesheets: [
       'components/bootstrap-' + getVersion('bootstrap') + '/css/bootstrap.min.css',
-      'components/open-sans-fontface-' + getVersion('open-sans-fontface') + '/open-sans.css',
       'css/prettify-theme.css',
+      'css/angular-topnav.css',
       'css/docs.css',
       'css/animations.css'
     ]
