@@ -2,7 +2,6 @@
 
 /* eslint-disable no-invalid-this */
 
-var bower = require('bower');
 var util = require('./utils.js');
 var npmRun = require('npm-run');
 
@@ -38,7 +37,7 @@ module.exports = function(grunt) {
   });
 
 
-  grunt.registerTask('docs', 'create angular docs', function() {
+  grunt.registerTask('docs', 'create AngularJS docs', function() {
     npmRun.execSync('gulp --gulpfile docs/gulpfile.js', {stdio: 'inherit'});
   });
 
@@ -64,14 +63,8 @@ module.exports = function(grunt) {
     util.collectErrors();
   });
 
-  grunt.registerTask('bower', 'Install Bower packages.', function() {
-    var done = this.async();
-
-    bower.commands.install()
-      .on('log', function(result) {
-        grunt.log.ok('bower: ' + result.id + ' ' + result.data.endpoint.name);
-      })
-      .on('error', grunt.fail.warn.bind(grunt.fail))
-      .on('end', done);
+  grunt.registerTask('firebaseDocsJsonForCI', function() {
+    util.firebaseDocsJsonForCI();
   });
+
 };
