@@ -9,21 +9,21 @@
  minErr,
  extend
 */
+
 /* eslint-disable no-unused-vars */
+function isFunction(value) { return typeof value === 'function'; }
+function isPromiseLike(obj) { return obj && isFunction(obj.then); }
+function isObject(value) { return value !== null && typeof value === 'object'; }
+function isUndefined(value) { return typeof value === 'undefined'; }
 
-var isFunction = function isFunction(value) {return typeof value === 'function';};
-var isPromiseLike = function isPromiseLike(obj) {return obj && isFunction(obj.then);};
-var isObject = function isObject(value) {return value != null && typeof value === 'object';};
-var isUndefined = function isUndefined(value) {return typeof value === 'undefined';};
-
-var minErr = function minErr(module, constructor) {
+function minErr(module, constructor) {
   return function() {
     var ErrorConstructor = constructor || Error;
     throw new ErrorConstructor(module + arguments[0] + arguments[1]);
   };
-};
+}
 
-var extend = function extend(dst) {
+function extend(dst) {
   for (var i = 1, ii = arguments.length; i < ii; i++) {
     var obj = arguments[i];
     if (obj) {
@@ -35,18 +35,11 @@ var extend = function extend(dst) {
     }
   }
   return dst;
-};
+}
+/* eslint-enable */
 
 var $q = qFactory(process.nextTick, function noopExceptionHandler() {});
 
 exports.resolved = $q.resolve;
 exports.rejected = $q.reject;
-exports.deferred = function() {
-    var deferred = $q.defer();
-
-    return {
-        promise: deferred.promise,
-        resolve: deferred.resolve,
-        reject: deferred.reject
-    };
-};
+exports.deferred = $q.defer;
