@@ -44,18 +44,18 @@ $provide.value("$locale", {
     ],
     "FIRSTDAYOFWEEK": 0,
     "MONTH": [
-      "jannewaris",
-      "febrewaris",
-      "maart",
-      "april",
-      "maaie",
-      "juny",
-      "july",
-      "augustus",
-      "septimber",
-      "oktober",
-      "novimber",
-      "desimber"
+      "Jannewaris",
+      "Febrewaris",
+      "Maart",
+      "April",
+      "Maaie",
+      "Juny",
+      "July",
+      "Augustus",
+      "Septimber",
+      "Oktober",
+      "Novimber",
+      "Desimber"
     ],
     "SHORTDAY": [
       "si",
@@ -67,32 +67,32 @@ $provide.value("$locale", {
       "so"
     ],
     "SHORTMONTH": [
-      "jan.",
-      "feb.",
-      "mrt.",
-      "apr.",
-      "mai",
-      "jun.",
-      "jul.",
-      "aug.",
-      "sep.",
-      "okt.",
-      "nov.",
-      "des."
+      "Jan",
+      "Feb",
+      "Mrt",
+      "Apr",
+      "Mai",
+      "Jun",
+      "Jul",
+      "Aug",
+      "Sep",
+      "Okt",
+      "Nov",
+      "Des"
     ],
     "STANDALONEMONTH": [
-      "jannewaris",
-      "febrewaris",
-      "maart",
-      "april",
-      "maaie",
-      "juny",
-      "july",
-      "augustus",
-      "septimber",
-      "oktober",
-      "novimber",
-      "desimber"
+      "Jannewaris",
+      "Febrewaris",
+      "Maart",
+      "April",
+      "Maaie",
+      "Juny",
+      "July",
+      "Augustus",
+      "Septimber",
+      "Oktober",
+      "Novimber",
+      "Desimber"
     ],
     "WEEKENDRANGE": [
       5,
