@@ -313,6 +313,7 @@ beforeEach(function() {
 
       function generateCompare(isNot) {
         return function(actual, namespace, code, content) {
+
           var matcher = new MinErrMatcher(isNot, namespace, code, content, {
             inputType: 'error',
             expectedAction: 'equal',
@@ -353,7 +354,78 @@ beforeEach(function() {
           return matcher.test(exception);
         };
       }
+    },
 
+    toBeMarkedAsSelected: function() {
+      // Selected is special because the element property and attribute reflect each other's state.
+
+      // Support: IE 9 only
+      // IE9 will wrongly report hasAttribute('selected') === true when the property is
+      // undefined or null, and the dev tools show that no attribute is set
+
+      return {
+        compare: function(actual) {
+          var errors = [];
+          var optionVal = toJson(actual.value);
+
+          if (actual.selected === null || typeof actual.selected === 'undefined' || actual.selected === false) {
+            errors.push('Expected option with value ' + optionVal + ' to have property "selected" set to truthy');
+          }
+
+          // Support: IE 9 only
+          if (msie !== 9 && actual.hasAttribute('selected') === false) {
+            errors.push('Expected option with value ' + optionVal + ' to have attribute "selected"');
+          }
+
+          var result = {
+            pass: errors.length === 0,
+            message: errors.join('\n')
+          };
+
+          return result;
+        },
+        negativeCompare: function(actual) {
+          var errors = [];
+          var optionVal = toJson(actual.value);
+
+          if (actual.selected) {
+            errors.push('Expected option with value ' + optionVal + ' property "selected" to be falsy');
+          }
+
+          // Support: IE 9 only
+          if (msie !== 9 && actual.hasAttribute('selected')) {
+            errors.push('Expected option with value ' + optionVal + ' not to have attribute "selected"');
+          }
+
+          var result = {
+            pass: errors.length === 0,
+            message: errors.join('\n')
+          };
+
+          return result;
+        }
+      };
+    },
+    toEqualSelect: function() {
+      return {
+        compare: function(actual, expected) {
+          var actualValues = [],
+              expectedValues = [].slice.call(arguments, 1);
+
+          forEach(actual.find('option'), function(option) {
+            actualValues.push(option.selected ? [option.value] : option.value);
+          });
+
+          var message = function() {
+            return 'Expected ' + toJson(actualValues) + ' to equal ' + toJson(expectedValues) + '.';
+          };
+
+          return {
+            pass: equals(expectedValues, actualValues),
+            message: message
+          };
+        }
+      };
     }
   });
 });
